IndexHandle

Enum IndexHandle 

pub enum IndexHandle {
    Owned(Box<ProverIndex<FULL_ROUNDS, Pallas, <OpeningProof<Pallas, FULL_ROUNDS> as OpenProof<Pallas, FULL_ROUNDS>>::SRS>>),
    Mmap(Box<MmapProverIndex<FULL_ROUNDS, Pallas, <OpeningProof<Pallas, FULL_ROUNDS> as OpenProof<Pallas, FULL_ROUNDS>>::SRS>>),
}
Fq companion of the Fp-side crate::pasta_fp_plonk_index::IndexHandle — selects between an owned ProverIndex and an MmapProverIndex whose bulk Vec<F> fields point into a mmap’d cache file. Both variants [Deref] to the same &ProverIndex so existing field-access patterns in this file continue to work via auto-deref.

Variants



Owned(Box<ProverIndex<FULL_ROUNDS, Pallas, <OpeningProof<Pallas, FULL_ROUNDS> as OpenProof<Pallas, FULL_ROUNDS>>::SRS>>)



Mmap(Box<MmapProverIndex<FULL_ROUNDS, Pallas, <OpeningProof<Pallas, FULL_ROUNDS> as OpenProof<Pallas, FULL_ROUNDS>>::SRS>>)

Methods from Deref<Target = ProverIndex<FULL_ROUNDS, Pallas, <OpeningProof<Pallas, FULL_ROUNDS> as OpenProof<Pallas, FULL_ROUNDS>>::SRS>>

pub fn verify( &self, witness: &[Vec<F>; 15], public: &[F], ) -> Result<(), GateError>

This function verifies the consistency of the wire assignments (witness) against the constraints

pub fn perm_quot( &self, lagrange: &WitnessOverDomains<F>, beta: F, gamma: F, z: &DensePolynomial<F>, alphas: impl Iterator<Item = F>, ) -> Result<(Evaluations<F, Radix2EvaluationDomain<F>>, DensePolynomial<F>), ProverError>

permutation quotient poly contribution computation

Errors

Will give error if polynomial division fails.

Panics

Will panic if power of alpha is missing.

pub fn perm_lnrz( &self, e: &ProofEvaluations<PointEvaluations<F>>, zeta: F, beta: F, gamma: F, alphas: impl Iterator<Item = F>, ) -> Evaluations<F, Radix2EvaluationDomain<F>>

permutation linearization poly contribution computation

pub fn perm_aggreg( &self, witness: &[Vec<F>; 15], beta: &F, gamma: &F, rng: &mut (impl RngCore + CryptoRng), ) -> Result<DensePolynomial<F>, ProverError>

permutation aggregation polynomial computation

Errors

Will give error if permutation result is not correct.

Panics

Will panic if first element is not 1.

pub fn verifier_index_digest<EFqSponge>(&self) -> <G as AffineRepr>::BaseField
where EFqSponge: Clone + FqSponge<<G as AffineRepr>::BaseField, G, <G as AffineRepr>::ScalarField, FULL_ROUNDS>, VerifierIndex<FULL_ROUNDS, G, Srs>: Clone,

Retrieve or compute the digest for the corresponding verifier index.

pub fn verifier_index(&self) -> VerifierIndex<FULL_ROUNDS, G, Srs>
where VerifierIndex<FULL_ROUNDS, G, Srs>: Clone,

Produces the VerifierIndex from the prover’s ProverIndex.

Panics

Will panic if srs cannot be in cell.